#!/usr/bin/env python3

import bs4

import ftfy

import parsel


def remove_trailing_chars(text: str) -> str:
    """
    Removes any trailing whitespace characters from the input string.
    """
    text: list[str] = text.split()
    text: list[str] = [word for word in text if word != ""]
    text = " ".join(text)
    return text


class ParselGetSelectorInText:
    def traverse_soup(self, root) -> None:
        """
        Traverses a BeautifulSoup object recursively, extracting all NavigableStrings,
        removing mojibake and extracting their text.
        """
        children_list = list(root.children)
        for child in children_list:
            if isinstance(child, bs4.element.NavigableString):
                text: str = child.get_text(separator=" ")
                text = remove_trailing_chars(text=text)
                if text != "":
                    text = ftfy.fix_text(text=text)
                    self.total_text += text + "\n"
            else:
                self.traverse_soup(root=child)
        return None

    def get_sel_results(self, sel_results: parsel.SelectorList) -> None:
        """
        Takes a list of Selector objects and extracts
        all NavigableStrings from their HTML.
        """
        for row in sel_results:
            html: str = row.get()
            soup = bs4.BeautifulSoup(html, features="lxml")
            self.traverse_soup(root=soup)
        return None

    def get_xpath_results(
        self,
        parsel_sel: parsel.Selector,
        xpath: str
            ) -> str:
        """
        Extracts all text results from an XPath
        query on a parsel Selector object.
        """
        self.total_text: str = ""
        sel_results = parsel_sel.xpath(xpath)
        self.get_sel_results(sel_results=sel_results)
        self.total_text.rstrip("\n")
        return self.total_text


def parsel_sel_get_text(parsel_sel: parsel.Selector, xpath: str) -> str:
    """
    Extracts all text results from an XPath
    query on a parsel Selector object.
    """
    sel_text_obj = ParselGetSelectorInText()

    total_text: str = sel_text_obj.get_xpath_results(
        parsel_sel=parsel_sel,
        xpath=xpath
    )
    return total_text



#!/usr/bin/env python3

from setuptools import setup

with open("README.md", "r") as f:
    readme = f.read()

setup(
    name="parsel_get_selector_text",
    packages=["parsel_get_selector_text"],
    version="0.2",
    license="MIT",
    description="Extracts all text results from an XPath "\
        "query on a parsel Selector object.",
    long_description=readme,
    long_description_content_type="text/markdown",
    author="Carlos A. Planchón",
    author_email="carlosandresplanchonprestes@gmail.com",
    url="https://github.com/carlosplanchon/parsel_get_selector_text",
    download_url="https://github.com/carlosplanchon/"
        "parsel_get_selector_text/archive/v0.2.tar.gz",
    keywords=["comment", "remover"],
    classifiers=[
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.11",
    ],
)
